# Copyright 2023 Jetperch LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from PySide6 import QtCore, QtWidgets
from joulescope_ui import N_


class ErrorMessageBox(QtWidgets.QDialog):
    """Display user-meaningful help information."""

    dialogs = []

    def __init__(self, parent, value):
        super().__init__(parent=parent)
        self.setWindowFlag(QtCore.Qt.WindowType.WindowStaysOnTopHint)

        self.setObjectName("error_dialog")
        self._layout = QtWidgets.QVBoxLayout(self)

        self._label = QtWidgets.QLabel(value, self)
        self._label.setWordWrap(True)
        self._layout.addWidget(self._label)

        self._spacer = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self._layout.addItem(self._spacer)

        self._buttons = QtWidgets.QDialogButtonBox(QtWidgets.QDialogButtonBox.Ok)
        self._buttons.accepted.connect(self.accept)
        self._buttons.rejected.connect(self.reject)
        self._layout.addWidget(self._buttons)

        self.resize(600, 400)
        self.setWindowTitle(N_('Error'))
        self.finished.connect(self._on_finish)

        self.open()
        ErrorMessageBox.dialogs.append(self)

    def _on_finish(self):
        self.close()
        ErrorMessageBox.dialogs.remove(self)
